@@ -14,5 +14,5 @@ function(t.vec,d.vec,alpha,S.plot=TRUE,S.col="black"){
     points(t.sort[d.sort==0],S[d.sort==0],pch=3,cex=2,col=S.col)
   }
   
-  list( time=t.sort,surv=S )
+  list( tau=alpha/(alpha+2), time=t.sort,surv=S )
 }
